# -*- coding: utf-8 -*-
import datetime
from django.db import models


class Service(models.Model):
    name = models.CharField(max_length=255, blank=False, null=False,
                            help_text='Nom du service')
    
    def __unicode__(self):
        return self.name

class Offer(models.Model):
    name = models.CharField(max_length=255, blank=False, null=False,
                            help_text='Nom de l\'offre')
    billing_period = models.IntegerField(blank=False, null=False, default=1,
                                       help_text='Période de facturation en mois')
    period_fees = models.DecimalField(max_digits=5, decimal_places=2,
                                      blank=False, null=False,
                                      help_text='Montant par période de facturation en €')
    initial_fees = models.DecimalField(max_digits=5, decimal_places=2,
                                      blank=False, null=False,
                                      help_text='Frais de mise en service en €')
    service = models.ForeignKey('Service')
    
    def __unicode__(self):
        return u'%s - %d€ / %im [%s]' % (self.name, self.period_fees, self.billing_period, self.service)

    class Meta:
        verbose_name = 'Offre'


class OfferSubscription(models.Model):
    subscription_date = models.DateField(
        null=False,
        blank=False,
        default=datetime.date.today,
        help_text='Date de souscription à l\'offre')
    resign_date = models.DateField(
        null=True,
        blank=True,
        help_text='Date de résiliation')
    commitment = models.IntegerField(blank=False, null=False,
                                     help_text='Période d\'engagement en mois',
                                     default=0)
    member = models.ForeignKey('members.Member', verbose_name='Membre')
    offer = models.ForeignKey('Offer', verbose_name='Offre')

    def __unicode__(self):
        return u'%s - %s - %s' % (self.member, self.offer.name, self.subscription_date)

    class Meta:
        verbose_name = 'Abonement'
